@@ -486,6 +486,10 @@ class RestAPI(object):
 		if response["error"] != None: return response
 		data["api_key"] = response["api_key"]
 
+		# add to self variables.
+		self.uid_api_keys[uid] = data["api_key"]
+		self.__plans__["free"]["api_keys"].append(data["api_key"])
+
 		# save new data.
 		response = self.firebase.firestore.save(reference, data) 
 		if response["error"] != None: return response
